==> kubernetes-model-autoscaling-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface HorizontalPodAutoscalerSpecFluent<A extends HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBehavior instead.
   * @return The buildable object.
   */
  @Deprecated
  public HorizontalPodAutoscalerBehavior getBehavior();
  public HorizontalPodAutoscalerBehavior buildBehavior();
  public A withBehavior(HorizontalPodAutoscalerBehavior behavior);
  public Boolean hasBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
  public Integer getMaxReplicas();
  public A withMaxReplicas(Integer maxReplicas);
  public Boolean hasMaxReplicas();
  public A addToMetrics(Integer index,MetricSpec item);
  public A setToMetrics(Integer index,MetricSpec item);
  public A addToMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2.MetricSpec... items);
  public A addAllToMetrics(Collection<MetricSpec> items);
  public A removeFromMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2.MetricSpec... items);
  public A removeAllFromMetrics(Collection<MetricSpec> items);
  public A removeMatchingFromMetrics(Predicate<MetricSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMetrics instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MetricSpec> getMetrics();
  public List<MetricSpec> buildMetrics();
  public MetricSpec buildMetric(Integer index);
  public MetricSpec buildFirstMetric();
  public MetricSpec buildLastMetric();
  public MetricSpec buildMatchingMetric(Predicate<MetricSpecBuilder> predicate);
  public Boolean hasMatchingMetric(Predicate<MetricSpecBuilder> predicate);
  public A withMetrics(List<MetricSpec> metrics);
  public A withMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2.MetricSpec... metrics);
  public Boolean hasMetrics();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(MetricSpec item);
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(Integer index,MetricSpec item);
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(Integer index);
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(Predicate<MetricSpecBuilder> predicate);
  public Integer getMinReplicas();
  public A withMinReplicas(Integer minReplicas);
  public Boolean hasMinReplicas();
  
  /**
   * This method has been deprecated, please use method buildScaleTargetRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public CrossVersionObjectReference getScaleTargetRef();
  public CrossVersionObjectReference buildScaleTargetRef();
  public A withScaleTargetRef(CrossVersionObjectReference scaleTargetRef);
  public Boolean hasScaleTargetRef();
  public A withNewScaleTargetRef(String apiVersion,String kind,String name);
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(CrossVersionObjectReference item);
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(CrossVersionObjectReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BehaviorNested<N> extends Nested<N>,HorizontalPodAutoscalerBehaviorFluent<HorizontalPodAutoscalerSpecFluent.BehaviorNested<N>>{
    public N and();
    public N endBehavior();
    
  }
  public interface MetricsNested<N> extends Nested<N>,MetricSpecFluent<HorizontalPodAutoscalerSpecFluent.MetricsNested<N>>{
    public N and();
    public N endMetric();
    
  }
  public interface ScaleTargetRefNested<N> extends Nested<N>,CrossVersionObjectReferenceFluent<HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{
    public N and();
    public N endScaleTargetRef();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface HorizontalPodAutoscalerSpecFluent<A extends HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBehavior instead.
   * @return The buildable object.
   */
  @Deprecated
  public HorizontalPodAutoscalerBehavior getBehavior();
  public HorizontalPodAutoscalerBehavior buildBehavior();
  public A withBehavior(HorizontalPodAutoscalerBehavior behavior);
  public Boolean hasBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> withNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehavior();
  public HorizontalPodAutoscalerSpecFluent.BehaviorNested<A> editOrNewBehaviorLike(HorizontalPodAutoscalerBehavior item);
  public Integer getMaxReplicas();
  public A withMaxReplicas(Integer maxReplicas);
  public Boolean hasMaxReplicas();
  public A addToMetrics(int index,MetricSpec item);
  public A setToMetrics(int index,MetricSpec item);
  public A addToMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2.MetricSpec... items);
  public A addAllToMetrics(Collection<MetricSpec> items);
  public A removeFromMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2.MetricSpec... items);
  public A removeAllFromMetrics(Collection<MetricSpec> items);
  public A removeMatchingFromMetrics(Predicate<MetricSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMetrics instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MetricSpec> getMetrics();
  public List<MetricSpec> buildMetrics();
  public MetricSpec buildMetric(int index);
  public MetricSpec buildFirstMetric();
  public MetricSpec buildLastMetric();
  public MetricSpec buildMatchingMetric(Predicate<MetricSpecBuilder> predicate);
  public Boolean hasMatchingMetric(Predicate<MetricSpecBuilder> predicate);
  public A withMetrics(List<MetricSpec> metrics);
  public A withMetrics(io.fabric8.kubernetes.api.model.autoscaling.v2.MetricSpec... metrics);
  public Boolean hasMetrics();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(MetricSpec item);
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(int index,MetricSpec item);
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(int index);
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
  public HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(Predicate<MetricSpecBuilder> predicate);
  public Integer getMinReplicas();
  public A withMinReplicas(Integer minReplicas);
  public Boolean hasMinReplicas();
  
  /**
   * This method has been deprecated, please use method buildScaleTargetRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public CrossVersionObjectReference getScaleTargetRef();
  public CrossVersionObjectReference buildScaleTargetRef();
  public A withScaleTargetRef(CrossVersionObjectReference scaleTargetRef);
  public Boolean hasScaleTargetRef();
  public A withNewScaleTargetRef(String apiVersion,String kind,String name);
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(CrossVersionObjectReference item);
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
  public HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(CrossVersionObjectReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BehaviorNested<N> extends Nested<N>,HorizontalPodAutoscalerBehaviorFluent<HorizontalPodAutoscalerSpecFluent.BehaviorNested<N>>{
    public N and();
    public N endBehavior();
    
  }
  public interface MetricsNested<N> extends Nested<N>,MetricSpecFluent<HorizontalPodAutoscalerSpecFluent.MetricsNested<N>>{
    public N and();
    public N endMetric();
    
  }
  public interface ScaleTargetRefNested<N> extends Nested<N>,CrossVersionObjectReferenceFluent<HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{
    public N and();
    public N endScaleTargetRef();
    
  }
  
}
